const webpack = require('webpack');
const path = require('path');
const CleanPlugin = require('clean-webpack-plugin');
// const UglifyJs = require('uglifyjs-webpack-plugin');
// const UglifyCss = require('optimize-css-assets-webpack-plugin');
// const safeParser = require('postcss-safe-parser');
const Visualizer = require('webpack-visualizer-plugin');

module.exports = {
    mode: 'development' ,
    entry: {
        app: './src/component/CommonTable/Table.jsx'
    } ,
    devtool: 'cheap-module-source-map' ,
    output: {
        path: path.resolve('./lib') ,
        libraryTarget: 'umd' ,
        library: 'TmsCommonTable'
    } ,
    module: {
        rules: [
            {
                test: /\.jsx?$/ ,
                loader: 'babel!eslint' ,
                include: [
                    path.resolve('./src') ,
                    path.resolve('./node_modules/build-dev-server-client')
                ]
            } ,
            {
                test: /\.(png|jpe?g|gif|svg)(\?.*)?$/ ,
                loader: 'file' ,
                options: {
                    name: 'assets/image/[name].[ext]?[hash:7]'
                }
            } ,
            {
                test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/ ,
                loader: 'file' ,
                options: {
                    name: 'assets/media/[name].[ext]?[hash:7]'
                }
            } ,
            {
                test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/ ,
                loader: 'file' ,
                options: {
                    name: 'assets/font/[name].[ext]?[hash:7]'
                }
            } ,
            {
                test: /\.css$/ ,
                loaders: [ 'style' , 'css' ]
            } ,
            {
                test: /\.scss$/ ,
                loaders: [ 'style' , 'css' , 'sass' ]
            } ,
            {
                test: /\.less/ ,
                loaders: [ 'style' , 'css' , 'less' ]
            }
        ]
    } ,
    resolve: {
        extensions: [ '.js' , '.jsx' , '.scss' , '.css' , 'less' ] ,
        alias: {
            src: path.resolve('./src') ,
            model: path.resolve('./src/model') ,
            view: path.resolve('./src/view') ,
            component: path.resolve('./src/view/component') ,
            container: path.resolve('./src/view/container') ,
            router: path.resolve('./src/router') ,
            assets: path.resolve('./src/assets') ,
            store: path.resolve('./src/store') ,
            utils: path.resolve('./src/utils')
        }
    } ,
    resolveLoader: {
        moduleExtensions: [ '-loader' ]
    } ,
    plugins: [
        new webpack.DefinePlugin({
            'process.env.IS_DEV': process.env.BUILD_ENV === 'dev' ,
            'process.env.IS_TEST': process.env.BUILD_ENV === 'test' ,
            'process.env.IS_PROD': process.env.BUILD_ENV === 'prod'
        }) ,
        new CleanPlugin([ path.resolve('./lib') ] , {allowExternal: true}) ,
        new Visualizer()

    ] ,
    externals: {
        react: 'react' ,
        antd: 'antd' ,
        moment: 'moment' ,
        'react-redux': 'react-redux' ,
        classnames: 'classnames' ,
        redux: 'redux' ,
        'redux-thunk': 'redux-thunk' ,
        'styled-components': 'styled-components' ,
        'tms-request': 'tms-request' ,
        'prop-types': 'prop-types' ,
        'react-beautiful-dnd': 'react-beautiful-dnd'
    } /*,
     optimization: {
     minimizer: [
     new UglifyJs({
     parallel: true ,
     uglifyOptions: {
     compress: {
     warnings: false ,
     drop_console: true ,
     drop_debugger: true
     } ,
     output: {
     comments: false
     }
     }
     }) ,
     new UglifyCss({
     cssProcessorOptions: {
     parser: safeParser ,
     discardComments: {removeAll: true}
     }
     })
     ]
     }*/
};
