import React from 'react';
import { Button, Popover, Input, Form, Checkbox } from 'antd';
import styled from 'styled-components';

const Pop = styled(Form)`
    .ant-row.ant-form-item {
        margin-bottom: 4px;
    }
    > a {
        display: block;
        margin-bottom: 4px;
    }
`;

const CheckBoxWrapper = styled.div`
    margin: 4px 0;
`;

export function CommonSearchFilter(props) {
    const {
        outerFilter,
        columns,
        onReset = () => {},
        onFilterColumnSearch = () => {},
        onFilterColumnCheck = () => {},
        filterColumnsSearchText,
        filterColumns
    } = props;

    return do {
        if (outerFilter) {
            <Popover
                trigger="click"
                arrowPointAtCenter
                placement="bottom"
                content={
                    <Pop>
                        <Form.Item>
                            <Input.Search
                                placeholder="请输入搜索内容"
                                onChange={onFilterColumnSearch}
                                value={filterColumnsSearchText}
                            />
                        </Form.Item>
                        <a href="javascript:void(0)" onClick={onReset}>
                            恢复缺省值
                        </a>
                        <Form.Item>
                            <Checkbox.Group
                                value={filterColumns}
                                onChange={onFilterColumnCheck}
                            >
                                {columns
                                    .filter(item => {
                                        if (!filterColumnsSearchText) {
                                            return true;
                                        }
                                        return (
                                            item.title
                                                .toLowerCase()
                                                .indexOf(
                                                    filterColumnsSearchText
                                                        .toLowerCase()
                                                        .trim()
                                                ) > -1
                                        );
                                    })
                                    .sort(item => {
                                        if (item.allowFilter) {
                                            return 1;
                                        }
                                    })
                                    .map(item => {
                                        const { title, allowFilter } = item;
                                        return (
                                            <CheckBoxWrapper key={title}>
                                                <Checkbox
                                                    value={title}
                                                    disabled={!allowFilter}
                                                >
                                                    {title}
                                                </Checkbox>
                                            </CheckBoxWrapper>
                                        );
                                    })}
                            </Checkbox.Group>
                        </Form.Item>
                    </Pop>
                }
            >
                <Button icon="filter">列</Button>
            </Popover>;
        }
    };
}
