import React from 'react';
import { Form } from 'antd';
import styled from 'styled-components';

const StyledForm = styled(Form)`
    display: flex;
    width: ${props => {
        return props['data-full-text-search'] ? '550px' : '750px';
    }};
    flex-wrap: wrap;
`;

const StyledFormItem = styled(Form.Item)`
    width: ${props => {
        return props['data-full-text-search'] ? '50%' : 'calc(100%/3)';
    }};
    padding-right: 10px;
    margin-bottom: 0;
    display: ${props => {
        const { index, expand } = props;
        const columnNum = props['data-full-text-search'] ? 2 : 3;
        if (index >= columnNum && !expand) {
            return 'none';
        }
    }};
    .ant-form-item-label {
        text-align: left;
    }
`;

const formItemLayout = {
    labelCol: { span: 7 },
    wrapperCol: { span: 17 }
};

export const CommonSearchForm = function CommonSearchForm(props) {
    const { form, searchItems, fullTextSearch, expand } = props;
    return (
        <StyledForm data-full-text-search={fullTextSearch}>
            {searchItems.map((item, index) => {
                const {
                    label,
                    fieldName,
                    fieldOptions,
                    component,
                    itemOptions
                } = item;
                return (
                    <StyledFormItem
                        {...formItemLayout}
                        key={fieldName}
                        colon={false}
                        label={label}
                        data-full-text-search={fullTextSearch}
                        {...itemOptions}
                        expand={expand}
                        index={index}
                    >
                        {form.getFieldDecorator(fieldName, fieldOptions)(
                            component
                        )}
                    </StyledFormItem>
                );
            })}
        </StyledForm>
    );
};
